@@ -6,8 +6,8 @@ import (
 	"sync"
 	"time"
 
+	"github.com/turbot/go-kit/helpers"
 	"github.com/turbot/steampipe/pkg/steampipeconfig"
-	"github.com/turbot/steampipe/pkg/utils"
 )
 
 // only allow one execution of refresh connections
@@ -16,13 +16,19 @@ var executeLock sync.Mutex
 // only allow one queued execution
 var queueLock sync.Mutex
 
-func RefreshConnections(ctx context.Context, forceUpdateConnectionNames ...string) *steampipeconfig.RefreshConnectionResult {
-	utils.LogTime("RefreshConnections start")
-	defer utils.LogTime("RefreshConnections end")
+func RefreshConnections(ctx context.Context, pluginManager pluginManager, forceUpdateConnectionNames ...string) (res *steampipeconfig.RefreshConnectionResult) {
+	log.Println("[INFO] RefreshConnections start")
+	defer log.Println("[INFO] RefreshConnections end")
+
+	// TODO KAI if we, for example, access a nil map, this does not seem to catch it and startup hangs
+	defer func() {
+		if r := recover(); r != nil {
+			res = steampipeconfig.NewErrorRefreshConnectionResult(helpers.ToError(r))
+		}
+	}()
 
 	t := time.Now()
-	log.Printf("[INFO] refreshConnections start")
-	defer log.Printf("[INFO] refreshConnections complete (%fs)", time.Since(t).Seconds())
+	defer log.Printf("[INFO] refreshConnections completion time (%fs)", time.Since(t).Seconds())
 
 	// first grab the queue lock
 	if !queueLock.TryLock() {
@@ -45,12 +51,12 @@ func RefreshConnections(ctx context.Context, forceUpdateConnectionNames ...strin
 	log.Printf("[INFO] acquired refreshExecuteLock, released refreshQueueLock")
 
 	// now refresh connections
-	// package up all necessary data into a state object6
-	state, err := newRefreshConnectionState(ctx, forceUpdateConnectionNames)
+
+	// package up all necessary data into a state object
+	state, err := newRefreshConnectionState(ctx, pluginManager, forceUpdateConnectionNames)
 	if err != nil {
 		return steampipeconfig.NewErrorRefreshConnectionResult(err)
 	}
-	defer state.close()
 
 	// now do the refresh
 	state.refreshConnections(ctx)
