@@ -14,6 +14,7 @@ import (
 	"github.com/spf13/cobra"
 	"github.com/spf13/viper"
 	"github.com/turbot/go-kit/helpers"
+	"github.com/turbot/steampipe-plugin-sdk/v5/grpc/proto"
 	"github.com/turbot/steampipe-plugin-sdk/v5/plugin"
 	"github.com/turbot/steampipe-plugin-sdk/v5/sperr"
 	"github.com/turbot/steampipe/pkg/constants"
@@ -44,9 +45,9 @@ type refreshConnectionState struct {
 	exemplarSchemaMapMut sync.Mutex
 
 	// maps keyed by plugin which gives an exemplar connection name,
-	// if a plugin has an entry in this map, all connections schemas can be cloned from teh exemplar schema
+	// if a plugin has an entry in this map, all connections schemas can be cloned from the exemplar schema
 	exemplarSchemaMap map[string]string
-	// if a plugin has an entry in this map, all connections schemas can be cloned from teh exemplar schema
+	// if a plugin has an entry in this map, all connections schemas can be cloned from the exemplar schema
 	exemplarCommentsMap map[string]string
 	pluginManager       pluginManager
 }
@@ -110,23 +111,26 @@ func (s *refreshConnectionState) refreshConnections(ctx context.Context) {
 		return
 	}
 
+	// if any connections in the final state are in error, that may mean we failed to start them
+	// - update the connection state table
+	if err := s.setFailedConnectionsToError(ctx); err != nil {
+		s.res.Error = err
+		return
+	}
+
 	log.Printf("[INFO] created connectionUpdates")
 
 	//  reload plugin rate limiter definitions for all plugins which are updated - the plugin will already be loaded
-	if len(s.connectionUpdates.PluginsWithUpdatedBinary) > 0 {
-		updatedPluginLimiters, err := s.pluginManager.LoadPluginRateLimiters(s.connectionUpdates.PluginsWithUpdatedBinary)
+	// also repopulate the plugin column table
+	if err := s.updateRateLimiterDefinitions(ctx); err != nil {
+		s.res.Error = err
+		return
+	}
 
-		if err != nil {
-			s.res.Error = err
-			return
-		}
-
-		if len(updatedPluginLimiters) > 0 {
-			err := s.pluginManager.HandlePluginLimiterChanges(updatedPluginLimiters)
-			if err != nil {
-				s.pluginManager.SendPostgresErrorsAndWarningsNotification(ctx, error_helpers.NewErrorsAndWarning(err))
-			}
-		}
+	// update the plugin column table, based on connection updates and plugins with updated binaries
+	if err := s.updatePluginColumnTable(ctx); err != nil {
+		s.res.Error = err
+		return
 	}
 
 	// delete the connection state file - it will be rewritten when we are complete
@@ -147,8 +151,10 @@ func (s *refreshConnectionState) refreshConnections(ctx context.Context) {
 
 	// NOTE: delete any DYNAMIC plugin connections which will be updated
 	// to avoid them being accessed before they are updated
-	// TODO sure we can remove this
-	s.executeDeleteQueries(ctx, s.connectionUpdates.DynamicUpdates())
+	if err := s.executeDeleteQueries(ctx, s.connectionUpdates.DynamicUpdates()); err != nil {
+		s.res.Error = err
+		return
+	}
 
 	// update connectionState table to reflect the updates (i.e. set connections to updating/deleting/ready as appropriate)
 	// also this will update the schema hashes of plugins
@@ -175,6 +181,91 @@ func (s *refreshConnectionState) refreshConnections(ctx context.Context) {
 	s.res.UpdatedConnections = true
 }
 
+func (s *refreshConnectionState) setFailedConnectionsToError(ctx context.Context) error {
+	conn, err := s.pool.Acquire(ctx)
+	if err != nil {
+		return sperr.WrapWithMessage(err, "failed to update connection state table")
+	}
+	defer conn.Release()
+
+	for _, c := range s.connectionUpdates.FinalConnectionState {
+		if c.State == constants.ConnectionStateError {
+			if err := s.tableUpdater.onConnectionError(ctx, conn.Conn(), c.ConnectionName, fmt.Errorf(c.Error())); err != nil {
+				return sperr.WrapWithMessage(err, "failed to update connection state table")
+			}
+		}
+	}
+	return nil
+}
+
+// if any plugin binaries have changed update the rate limiter definitions
+func (s *refreshConnectionState) updateRateLimiterDefinitions(ctx context.Context) error {
+	if len(s.connectionUpdates.PluginsWithUpdatedBinary) == 0 {
+		return nil
+	}
+
+	updatedPluginLimiters, err := s.pluginManager.LoadPluginRateLimiters(s.connectionUpdates.PluginsWithUpdatedBinary)
+
+	if err != nil {
+		return err
+	}
+
+	if len(updatedPluginLimiters) > 0 {
+		err := s.pluginManager.HandlePluginLimiterChanges(updatedPluginLimiters)
+		if err != nil {
+			s.pluginManager.SendPostgresErrorsAndWarningsNotification(ctx, error_helpers.NewErrorsAndWarning(err))
+		}
+	}
+	return nil
+}
+
+// if any plugin binaries have changed update the plugin column table
+func (s *refreshConnectionState) updatePluginColumnTable(ctx context.Context) error {
+	var deletedPlugins []string
+	var updatedPlugins = map[string]*proto.Schema{}
+
+	currentPluginConnectionMap := s.connectionUpdates.CurrentConnectionState.GetPluginToConnectionMap()
+	finalPluginConnectionMap := s.connectionUpdates.FinalConnectionState.GetPluginToConnectionMap()
+
+	// add into plugin column table any plugins which have connections for the first time
+	for _, connectionState := range s.connectionUpdates.Update {
+		connectionName := connectionState.ConnectionName
+		if connectionState.SchemaMode == plugin.SchemaModeDynamic {
+			// plugin column table only supports static for now
+			continue
+		}
+		p := connectionState.Plugin
+		if _, ok := currentPluginConnectionMap[p]; !ok {
+			updatedPlugins[p] = s.connectionUpdates.ConnectionPlugins[connectionName].ConnectionMap[connectionName].Schema
+		}
+	}
+
+	// remove from plugin column table any plugins which have no connections
+	for connectionName := range s.connectionUpdates.Delete {
+		// get plugin for this connection
+		connectionState, ok := s.connectionUpdates.CurrentConnectionState[connectionName]
+		if !ok {
+			continue
+		}
+
+		p := connectionState.Plugin
+		if _, ok := finalPluginConnectionMap[p]; !ok {
+			deletedPlugins = append(deletedPlugins, p)
+		}
+	}
+
+	// update plugin column table for any plugins which have updated binaries
+	for p, connectionName := range s.connectionUpdates.PluginsWithUpdatedBinary {
+		// do we actually have a connection plugin for this plugin?
+		if connectionPlugin, ok := s.connectionUpdates.ConnectionPlugins[connectionName]; ok {
+			updatedPlugins[p] = connectionPlugin.ConnectionMap[connectionName].Schema
+		}
+	}
+
+	return s.pluginManager.UpdatePluginColumnsTable(ctx, updatedPlugins, deletedPlugins)
+
+}
+
 func (s *refreshConnectionState) addMissingPluginWarnings() {
 	log.Printf("[INFO] refreshConnections: identify missing plugins")
 
@@ -208,7 +299,7 @@ func (s *refreshConnectionState) logRefreshConnectionResults() {
 
 	var op strings.Builder
 	if s.connectionUpdates != nil {
-		op.WriteString(fmt.Sprintf("%s", s.connectionUpdates.String()))
+		op.WriteString(s.connectionUpdates.String())
 	}
 	if s.res != nil {
 		op.WriteString(fmt.Sprintf("%s\n", s.res.String()))
@@ -415,7 +506,9 @@ func (s *refreshConnectionState) executeUpdateSetsInParallel(ctx context.Context
 				errors = append(errors, connectionError.err)
 				conn, poolErr := s.pool.Acquire(ctx)
 				if poolErr == nil {
-					s.tableUpdater.onConnectionError(ctx, conn.Conn(), connectionError.name, connectionError.err)
+					if err := s.tableUpdater.onConnectionError(ctx, conn.Conn(), connectionError.name, connectionError.err); err != nil {
+						log.Println("[WARN] failed to update connection state table", err.Error())
+					}
 					conn.Release()
 				}
 			}
@@ -462,7 +555,7 @@ func (s *refreshConnectionState) executeUpdateForConnections(ctx context.Context
 
 	for _, connectionState := range connectionStates {
 		connectionName := connectionState.ConnectionName
-		remoteSchema := utils.PluginFQNToSchemaName(connectionState.Plugin)
+		pluginSchemaName := utils.PluginFQNToSchemaName(connectionState.Plugin)
 		var sql string
 
 		s.exemplarSchemaMapMut.Lock()
@@ -473,7 +566,7 @@ func (s *refreshConnectionState) executeUpdateForConnections(ctx context.Context
 			sql = getCloneSchemaQuery(exemplarSchemaName, connectionState)
 		} else {
 			// just get sql to execute update query, and update the connection state table, in a transaction
-			sql = db_common.GetUpdateConnectionQuery(connectionName, remoteSchema)
+			sql = db_common.GetUpdateConnectionQuery(connectionName, pluginSchemaName)
 		}
 		s.exemplarSchemaMapMut.Unlock()
 
@@ -736,9 +829,9 @@ func (s *refreshConnectionState) executeDeleteQuery(ctx context.Context, connect
 	}
 	defer func() {
 		if err != nil {
-			tx.Rollback(ctx)
+			_ = tx.Rollback(ctx)
 		} else {
-			tx.Commit(ctx)
+			err = tx.Commit(ctx)
 		}
 	}()
 
