@@ -3,6 +3,7 @@ package db_client
 import (
 	"context"
 	"fmt"
+	"github.com/jackc/pgx/v5/pgconn"
 	"log"
 	"strings"
 	"sync"
@@ -12,7 +13,7 @@ import (
 	"github.com/spf13/viper"
 	"github.com/turbot/steampipe/pkg/constants"
 	"github.com/turbot/steampipe/pkg/db/db_common"
-	"github.com/turbot/steampipe/pkg/error_helpers"
+	"github.com/turbot/steampipe/pkg/serversettings"
 	"github.com/turbot/steampipe/pkg/steampipeconfig"
 	"github.com/turbot/steampipe/pkg/utils"
 	"golang.org/x/exp/maps"
@@ -22,7 +23,15 @@ import (
 // DbClient wraps over `sql.DB` and gives an interface to the database
 type DbClient struct {
 	connectionString string
-	pool             *pgxpool.Pool
+
+	// connection userPool for user initiated queries
+	userPool *pgxpool.Pool
+
+	// connection used to run system/plumbing queries (connection state, server settings)
+	managementPool *pgxpool.Pool
+
+	// the settings of the server that this client is connected to
+	serverSettings *db_common.ServerSettings
 
 	// this flag is set if the service that this client
 	// is connected to is running in the same physical system
@@ -33,7 +42,10 @@ type DbClient struct {
 
 	// map of database sessions, keyed to the backend_pid in postgres
 	// used to update session search path where necessary
+	// TODO: there's no code which cleans up this map when connections get dropped by pgx
+	// https://github.com/turbot/steampipe/issues/3737
 	sessions map[uint32]*db_common.DatabaseSession
+
 	// allows locked access to the 'sessions' map
 	sessionsMutex *sync.Mutex
 
@@ -50,7 +62,7 @@ type DbClient struct {
 	onConnectionCallback DbConnectionCallback
 }
 
-func NewDbClient(ctx context.Context, connectionString string, onConnectionCallback DbConnectionCallback) (*DbClient, error) {
+func NewDbClient(ctx context.Context, connectionString string, onConnectionCallback DbConnectionCallback, opts ...ClientOption) (_ *DbClient, err error) {
 	utils.LogTime("db_client.NewDbClient start")
 	defer utils.LogTime("db_client.NewDbClient end")
 
@@ -76,25 +88,66 @@ func NewDbClient(ctx context.Context, connectionString string, onConnectionCallb
 		connectionString:     connectionString,
 	}
 
-	if err := client.establishConnectionPool(ctx); err != nil {
+	defer func() {
+		if err != nil {
+			// try closing the client
+			client.Close(ctx)
+		}
+	}()
+
+	config := clientConfig{}
+	for _, o := range opts {
+		o(&config)
+	}
+
+	if err := client.establishConnectionPool(ctx, config); err != nil {
+		return nil, err
+	}
+
+	// load up the server settings
+	if err := client.loadServerSettings(ctx); err != nil {
 		return nil, err
 	}
 
 	// set user search path
-	err := client.LoadUserSearchPath(ctx)
-	if err != nil {
+	if err := client.LoadUserSearchPath(ctx); err != nil {
 		return nil, err
 	}
 
 	// populate customSearchPath
 	if err := client.SetRequiredSessionSearchPath(ctx); err != nil {
-		client.Close(ctx)
 		return nil, err
 	}
 
 	return client, nil
 }
 
+func (c *DbClient) closePools() {
+	if c.userPool != nil {
+		c.userPool.Close()
+	}
+	if c.managementPool != nil {
+		c.managementPool.Close()
+	}
+}
+
+func (c *DbClient) loadServerSettings(ctx context.Context) error {
+	serverSettings, err := serversettings.Load(ctx, c.managementPool)
+	if err != nil {
+		if notFound := db_common.IsRelationNotFoundError(err); notFound {
+			// when connecting to pre-0.21.0 services, the steampipe_server_settings table will not be available.
+			// this is expected and not an error
+			// code which uses steampipe_server_settings should handle this
+			log.Printf("[TRACE] could not find %s.%s table. skipping\n", constants.InternalSchema, constants.ServerSettingsTable)
+			return nil
+		}
+		return err
+	}
+	c.serverSettings = serverSettings
+	log.Println("[TRACE] loaded server settings:", serverSettings)
+	return nil
+}
+
 func (c *DbClient) setShouldShowTiming(ctx context.Context, session *db_common.DatabaseSession) {
 	currentShowTimingFlag := viper.GetBool(constants.ArgTiming)
 
@@ -111,53 +164,50 @@ func (c *DbClient) shouldShowTiming() bool {
 	return c.showTimingFlag && !c.disableTiming
 }
 
-// Close implements Client
-// closes the connection to the database and shuts down the backend
-func (c *DbClient) Close(context.Context) error {
-	log.Printf("[TRACE] DbClient.Close %v", c.pool)
-	if c.pool != nil {
-		// clear the sessions map - so that we can't reuse it
-		c.sessions = nil
-		c.pool.Close()
-	}
-
-	return nil
+// ServerSettings returns the settings of the steampipe service that this DbClient is connected to
+//
+// Keep in mind that when connecting to pre-0.21.x servers, the server_settings data is not available. This is expected.
+// Code which read server_settings should take this into account.
+func (c *DbClient) ServerSettings() *db_common.ServerSettings {
+	return c.serverSettings
 }
 
-// RefreshSessions terminates the current connections and creates a new one - repopulating session data
-func (c *DbClient) RefreshSessions(ctx context.Context) (res *db_common.AcquireSessionResult) {
-	utils.LogTime("db_client.RefreshSessions start")
-	defer utils.LogTime("db_client.RefreshSessions end")
+// RegisterNotificationListener has an empty implementation
+// NOTE: we do not (currently) support notifications from remote connections
+func (c *DbClient) RegisterNotificationListener(func(notification *pgconn.Notification)) {}
 
-	if err := c.refreshDbClient(ctx); err != nil {
-		res.Error = err
-		return res
-	}
-	res = c.AcquireSession(ctx)
-	if res.Session != nil {
-		res.Session.Close(error_helpers.IsContextCanceled(ctx))
-	}
-	return res
+// Close implements Client
+
+// closes the connection to the database and shuts down the backend
+func (c *DbClient) Close(context.Context) error {
+	log.Printf("[TRACE] DbClient.Close %v", c.userPool)
+	c.closePools()
+	// nullify active sessions, since with the closing of the pools
+	// none of the sessions will be valid anymore
+	c.sessions = nil
+
+	return nil
 }
 
 // GetSchemaFromDB  retrieves schemas for all steampipe connections (EXCEPT DISABLED CONNECTIONS)
 // NOTE: it optimises the schema extraction by extracting schema information for
 // connections backed by distinct plugins and then fanning back out.
 func (c *DbClient) GetSchemaFromDB(ctx context.Context) (*db_common.SchemaMetadata, error) {
-	conn, _, err := c.GetDatabaseConnectionWithRetries(ctx)
+	log.Printf("[INFO] DbClient GetSchemaFromDB")
+	mgmtConn, err := c.managementPool.Acquire(ctx)
 	if err != nil {
 		return nil, err
 	}
-	defer conn.Release()
+	defer mgmtConn.Release()
 
 	// for optimisation purposes, try to load connection state and build a map of schemas to load
 	// (if we are connected to a remote server running an older CLI,
 	// this load may fail, in which case bypass the optimisation)
-	connectionStateMap, err := steampipeconfig.LoadConnectionState(ctx, conn.Conn(), steampipeconfig.WithWaitUntilLoading())
-	// NOTE: if we failed to load conenction state, this may be because we are connected to an older version of the CLI
+	connectionStateMap, err := steampipeconfig.LoadConnectionState(ctx, mgmtConn.Conn(), steampipeconfig.WithWaitUntilLoading())
+	// NOTE: if we failed to load connection state, this may be because we are connected to an older version of the CLI
 	// use legacy (v0.19.x) schema loading code
 	if err != nil {
-		return c.GetSchemaFromDBLegacy(ctx, conn)
+		return c.GetSchemaFromDBLegacy(ctx, mgmtConn)
 	}
 
 	// build a ConnectionSchemaMap object to identify the schemas to load
@@ -172,14 +222,8 @@ func (c *DbClient) GetSchemaFromDB(ctx context.Context) (*db_common.SchemaMetada
 	// build a query to retrieve these schemas
 	query := c.buildSchemasQuery(schemas...)
 
-	//execute
-	tablesResult, err := conn.Query(ctx, query)
-	if err != nil {
-		return nil, err
-	}
-
 	// build schema metadata from query result
-	metadata, err := db_common.BuildSchemaMetadata(tablesResult)
+	metadata, err := db_common.LoadSchemaMetadata(ctx, mgmtConn.Conn(), query)
 	if err != nil {
 		return nil, err
 	}
@@ -205,28 +249,17 @@ func (c *DbClient) GetSchemaFromDBLegacy(ctx context.Context, conn *pgxpool.Conn
 	// build a query to retrieve these schemas
 	query := c.buildSchemasQueryLegacy()
 
-	//execute
-	tablesResult, err := conn.Query(ctx, query)
-	if err != nil {
-		return nil, err
-	}
-
 	// build schema metadata from query result
-	return db_common.BuildSchemaMetadata(tablesResult)
+	return db_common.LoadSchemaMetadata(ctx, conn.Conn(), query)
 }
 
 // refreshDbClient terminates the current connection and opens up a new connection to the service.
-func (c *DbClient) refreshDbClient(ctx context.Context) error {
-	utils.LogTime("db_client.refreshDbClient start")
-	defer utils.LogTime("db_client.refreshDbClient end")
+func (c *DbClient) ResetPools(ctx context.Context) {
+	log.Println("[TRACE] db_client.ResetPools start")
+	defer log.Println("[TRACE] db_client.ResetPools end")
 
-	// close the connection pool and recreate
-	c.pool.Close()
-	if err := c.establishConnectionPool(ctx); err != nil {
-		return err
-	}
-
-	return nil
+	c.userPool.Reset()
+	c.managementPool.Reset()
 }
 
 func (c *DbClient) buildSchemasQuery(schemas ...string) string {
