@@ -3,6 +3,7 @@ package db_client
 import (
 	"context"
 	"database/sql"
+	"errors"
 	"fmt"
 	"net/netip"
 	"strings"
@@ -128,7 +129,7 @@ func (c *DbClient) ExecuteInSession(ctx context.Context, session *db_common.Data
 			statushooks.Done(ctxExecute)
 			// error - rollback transaction if we have one
 			if tx != nil {
-				tx.Rollback()
+				_ = tx.Rollback()
 			}
 			// in case of error call the onComplete callback
 			if onComplete != nil {
@@ -176,7 +177,7 @@ func (c *DbClient) getExecuteContext(ctx context.Context) context.Context {
 	}
 	// create a context with a deadline
 	shouldBeDoneBy := time.Now().Add(queryTimeout)
-	// we don't use this cancel fn because, pgx prematurely cancels the PG connection when this cancel gets called in 'defer'
+	//nolint:golint,lostcancel //we don't use this cancel fn because, pgx prematurely cancels the PG connection when this cancel gets called in 'defer'
 	newCtx, _ := context.WithDeadline(ctx, shouldBeDoneBy)
 
 	return newCtx
@@ -199,54 +200,44 @@ func (c *DbClient) getQueryTiming(ctx context.Context, startTime time.Time, sess
 		resultChannel <- timingResult
 	}()
 
-	res, err := c.ExecuteSyncInSession(ctx, session, fmt.Sprintf("select id, rows_fetched, cache_hit, hydrate_calls from %s.%s where id > %d", constants.InternalSchema, constants.ForeignTableScanMetadata, session.ScanMetadataMaxId))
-	// if we failed to read scan metadata (either because the query failed or the plugin does not support it)
-	// just return
-	if err != nil || len(res.Rows) == 0 {
+	var scanRows *ScanMetadataRow
+	err := db_common.ExecuteSystemClientCall(ctx, session.Connection.Conn(), func(ctx context.Context, tx pgx.Tx) error {
+		query := fmt.Sprintf("select id, rows_fetched, cache_hit, hydrate_calls from %s.%s where id > %d", constants.InternalSchema, constants.ForeignTableScanMetadata, session.ScanMetadataMaxId)
+		rows, err := tx.Query(ctx, query)
+		if err != nil {
+			return err
+		}
+		scanRows, err = pgx.CollectOneRow(rows, pgx.RowToAddrOfStructByName[ScanMetadataRow])
+		return err
+	})
+
+	// if we failed to read scan metadata (either because the query failed or the plugin does not support it) just return
+	// we don't return the error, since we don't want to error out in this case
+	if err != nil || scanRows == nil {
 		return
 	}
 
 	// so we have scan metadata - create the metadata struct
 	timingResult.Metadata = &queryresult.TimingMetadata{}
-	var id int64
-	for _, r := range res.Rows {
-		rw := r.(*queryresult.RowResult)
-		id = rw.Data[0].(int64)
-		rowsFetched := rw.Data[1].(int64)
-		cacheHit := rw.Data[2].(bool)
-		hydrateCalls := rw.Data[3].(int64)
-
-		timingResult.Metadata.HydrateCalls += hydrateCalls
-		if cacheHit {
-			timingResult.Metadata.CachedRowsFetched += rowsFetched
-		} else {
-			timingResult.Metadata.RowsFetched += rowsFetched
-		}
-
+	timingResult.Metadata.HydrateCalls += scanRows.HydrateCalls
+	if scanRows.CacheHit {
+		timingResult.Metadata.CachedRowsFetched += scanRows.RowsFetched
+	} else {
+		timingResult.Metadata.RowsFetched += scanRows.RowsFetched
 	}
 	// update the max id for this session
-	session.ScanMetadataMaxId = id
-
-	return
+	session.ScanMetadataMaxId = scanRows.Id
 }
 
 func (c *DbClient) updateScanMetadataMaxId(ctx context.Context, session *db_common.DatabaseSession) error {
-	res, err := c.ExecuteSyncInSession(ctx, session, fmt.Sprintf("select max(id) from %s.%s", constants.InternalSchema, constants.ForeignTableScanMetadata))
-	if err != nil {
-		return err
-	}
-
-	for _, r := range res.Rows {
-		rw := r.(*queryresult.RowResult)
-		id, ok := rw.Data[0].(int64)
-		if ok {
-			// update the max id for this session
-			session.ScanMetadataMaxId = id
+	return db_common.ExecuteSystemClientCall(ctx, session.Connection.Conn(), func(ctx context.Context, tx pgx.Tx) error {
+		row := tx.QueryRow(ctx, fmt.Sprintf("select max(id) from %s.%s", constants.InternalSchema, constants.ForeignTableScanMetadata))
+		err := row.Scan(&session.ScanMetadataMaxId)
+		if errors.Is(err, pgx.ErrNoRows) {
+			return nil
 		}
-
-		break
-	}
-	return nil
+		return err
+	})
 }
 
 // run query in a goroutine, so we can check for cancellation
