@@ -9,10 +9,8 @@ import (
 	"github.com/jackc/pgx/v5"
 	"github.com/spf13/viper"
 	"github.com/turbot/go-kit/helpers"
-	"github.com/turbot/steampipe/pkg/cmdconfig"
 	"github.com/turbot/steampipe/pkg/constants"
 	"github.com/turbot/steampipe/pkg/db/db_common"
-	"github.com/turbot/steampipe/pkg/steampipeconfig"
 )
 
 // SetRequiredSessionSearchPath implements Client
@@ -56,7 +54,7 @@ func (c *DbClient) SetRequiredSessionSearchPath(ctx context.Context) error {
 }
 
 func (c *DbClient) LoadUserSearchPath(ctx context.Context) error {
-	conn, _, err := c.GetDatabaseConnectionWithRetries(ctx)
+	conn, err := c.managementPool.Acquire(ctx)
 	if err != nil {
 		return err
 	}
@@ -88,28 +86,17 @@ func (c *DbClient) GetCustomSearchPath() []string {
 	return c.customSearchPath
 }
 
-// reload Steampipe config, update viper and re-set required search path
-func (c *DbClient) updateRequiredSearchPath(ctx context.Context) error {
-	config, errorsAndWarnings := steampipeconfig.LoadSteampipeConfig(viper.GetString(constants.ArgModLocation), "dashboard")
-	if errorsAndWarnings.GetError() != nil {
-		return errorsAndWarnings.GetError()
-	}
-	// todo review this usage of GlobalConfig
-	// https://github.com/turbot/steampipe/issues/3387
-	steampipeconfig.GlobalConfig = config
-	cmdconfig.SetDefaultsFromConfig(steampipeconfig.GlobalConfig.ConfigMap())
-	return c.SetRequiredSessionSearchPath(ctx)
-}
-
 // ensure the search path for the database session is as required
 func (c *DbClient) ensureSessionSearchPath(ctx context.Context, session *db_common.DatabaseSession) error {
 	log.Printf("[TRACE] ensureSessionSearchPath")
 
 	// update the stored value of user search path
+	// this might have changed if a connection has been added/removed
 	if err := c.loadUserSearchPath(ctx, session.Connection.Conn()); err != nil {
 		return err
 	}
 
+	// get the required search path which is either a custom search path (if present) or the user search path
 	requiredSearchPath := c.GetRequiredSessionSearchPath()
 
 	// now determine whether the session search path is the same as the required search path
@@ -122,7 +109,11 @@ func (c *DbClient) ensureSessionSearchPath(ctx context.Context, session *db_comm
 	// so we need to set the search path
 	log.Printf("[TRACE] session search path will be updated to  %s", strings.Join(c.customSearchPath, ","))
 
-	_, err := session.Connection.Exec(ctx, fmt.Sprintf("set search_path to %s", strings.Join(db_common.PgEscapeSearchPath(requiredSearchPath), ",")))
+	err := db_common.ExecuteSystemClientCall(ctx, session.Connection.Conn(), func(ctx context.Context, tx pgx.Tx) error {
+		_, err := tx.Exec(ctx, fmt.Sprintf("set search_path to %s", strings.Join(db_common.PgEscapeSearchPath(requiredSearchPath), ",")))
+		return err
+	})
+
 	if err == nil {
 		// update the session search path property
 		session.SearchPath = requiredSearchPath
