@@ -8,12 +8,12 @@ import (
 )
 
 // ExecuteQuery executes a single query. If shutdownAfterCompletion is true, shutdown the client after completion
-func ExecuteQuery(ctx context.Context, queryString string, client Client) (*queryresult.ResultStreamer, error) {
+func ExecuteQuery(ctx context.Context, client Client, queryString string, args ...any) (*queryresult.ResultStreamer, error) {
 	utils.LogTime("db.ExecuteQuery start")
 	defer utils.LogTime("db.ExecuteQuery end")
 
 	resultsStreamer := queryresult.NewResultStreamer()
-	result, err := client.Execute(ctx, queryString)
+	result, err := client.Execute(ctx, queryString, args...)
 	if err != nil {
 		return nil, err
 	}
