@@ -36,6 +36,17 @@ begin
 		RAISE EXCEPTION 'Unknown value % for set_cache - valid values are on, off and clear.', $1;
 	END IF;
 end;
+`,
+	},
+	{
+		Name:     constants.FunctionConnectionCacheClear,
+		Params:   map[string]string{"connection": "text"},
+		Returns:  "void",
+		Language: "plpgsql",
+		Body: `
+begin
+		INSERT INTO steampipe_internal.steampipe_settings("name","value") VALUES ('connection_cache_clear',connection);
+end;
 `,
 	},
 	{
