@@ -2,18 +2,19 @@ package db_local
 
 import (
 	"fmt"
-	filehelpers "github.com/turbot/go-kit/files"
 	"os"
 	"path/filepath"
 	"testing"
 	"time"
 
+	filehelpers "github.com/turbot/go-kit/files"
+
 	"github.com/turbot/steampipe/pkg/constants"
 	"github.com/turbot/steampipe/pkg/filepaths"
 )
 
 func TestTrimBackups(t *testing.T) {
-	filepaths.SteampipeDir = "~/.steampipe"
+	filepaths.SteampipeDir, _ = filehelpers.Tildefy("~/.steampipe")
 	// create backups more than MaxBackups
 	backupDir := filepaths.EnsureBackupsDir()
 	filesCreated := []string{}
