@@ -15,24 +15,23 @@ import (
 	psutils "github.com/shirou/gopsutil/process"
 	"github.com/spf13/viper"
 	"github.com/turbot/go-kit/helpers"
+	"github.com/turbot/steampipe-plugin-sdk/v5/sperr"
 	"github.com/turbot/steampipe/pkg/constants"
 	"github.com/turbot/steampipe/pkg/db/db_common"
 	"github.com/turbot/steampipe/pkg/error_helpers"
 	"github.com/turbot/steampipe/pkg/filepaths"
 	"github.com/turbot/steampipe/pkg/pluginmanager"
-	pb "github.com/turbot/steampipe/pkg/pluginmanager_service/grpc/proto"
 	"github.com/turbot/steampipe/pkg/statushooks"
-	"github.com/turbot/steampipe/pkg/steampipeconfig/modconfig"
 	"github.com/turbot/steampipe/pkg/utils"
-	"github.com/turbot/steampipe/sperr"
 )
 
 // StartResult is a pseudoEnum for outcomes of StartNewInstance
 type StartResult struct {
-	modconfig.ErrorAndWarnings
+	error_helpers.ErrorAndWarnings
 	Status             StartDbStatus
 	DbState            *RunningDBInstanceInfo
-	PluginManagerState *pluginmanager.PluginManagerState
+	PluginManagerState *pluginmanager.State
+	PluginManager      *pluginmanager.PluginManagerClient
 }
 
 func (r *StartResult) SetError(err error) *StartResult {
@@ -61,19 +60,27 @@ const (
 	ListenTypeLocal = "local"
 )
 
-// IsValid is a validator for StartListenType known values
-func (slt StartListenType) IsValid() error {
+// ToListenAddresses is transforms StartListenType known aliases into their actual value
+func (slt StartListenType) ToListenAddresses() []string {
 	switch slt {
-	case ListenTypeNetwork, ListenTypeLocal:
-		return nil
+	case ListenTypeNetwork:
+		return []string{"*"}
+	case ListenTypeLocal:
+		return []string{"localhost"}
 	}
-	return fmt.Errorf("Invalid listen type. Can be one of '%v' or '%v'", ListenTypeNetwork, ListenTypeLocal)
+	return strings.Split(string(slt), ",")
 }
 
-func StartServices(ctx context.Context, port int, listen StartListenType, invoker constants.Invoker) *StartResult {
+func StartServices(ctx context.Context, listenAddresses []string, port int, invoker constants.Invoker) *StartResult {
 	utils.LogTime("db_local.StartServices start")
 	defer utils.LogTime("db_local.StartServices end")
 
+	// we want the service to always listen on IPv4 loopback
+	if !utils.ListenAddressesContainsOneOfAddresses(listenAddresses, []string{"127.0.0.1", "*", "localhost"}) {
+		log.Println("[TRACE] StartServices - prepending 127.0.0.1 to listenAddresses")
+		listenAddresses = append([]string{"127.0.0.1"}, listenAddresses...)
+	}
+
 	res := &StartResult{}
 
 	// if we were not successful, stop services again
@@ -90,49 +97,69 @@ func StartServices(ctx context.Context, port int, listen StartListenType, invoke
 	}
 
 	if res.DbState == nil {
-		res = startDB(ctx, port, listen, invoker)
+		res = startDB(ctx, listenAddresses, port, invoker)
 		if res.Error != nil {
 			return res
 		}
 	} else {
 		res.Status = ServiceAlreadyRunning
+
+		// if the service is already running, also load the state of the plugin manager
+		pluginManagerState, err := pluginmanager.LoadState()
+		if err != nil {
+			res.Error = err
+			return res
+		}
+		res.PluginManagerState = pluginManagerState
 	}
 
-	// start plugin manager if needed
-	res = ensurePluginManager(res)
 	if res.Status == ServiceStarted {
 		// execute post startup setup
 		if err := postServiceStart(ctx, res); err != nil {
 			// NOTE do not update res.Status - this will be done by defer block
 			res.Error = err
+			return res
 		}
+
+		// start plugin manager if needed
+		pluginManager, pluginManagerState, err := ensurePluginManager()
+		res.PluginManagerState = pluginManagerState
+		res.PluginManager = pluginManager
+		if err != nil {
+			res.Error = err
+			return res
+		}
+
+		statushooks.SetStatus(ctx, "Service startup complete")
+
 	}
 	return res
 }
 
-func ensurePluginManager(res *StartResult) *StartResult {
+func ensurePluginManager() (*pluginmanager.PluginManagerClient, *pluginmanager.State, error) {
 	// start the plugin manager if needed
-	res.PluginManagerState, res.Error = pluginmanager.LoadPluginManagerState()
-	if res.Error != nil {
-		res.Status = ServiceFailedToStart
-		return res
+	state, err := pluginmanager.LoadState()
+	if err != nil {
+		return nil, nil, err
 	}
 
-	if !res.PluginManagerState.Running {
+	if !state.Running {
 		// get the location of the currently running steampipe process
 		executable, err := os.Executable()
 		if err != nil {
 			log.Printf("[WARN] plugin manager start() - failed to get steampipe executable path: %s", err)
-			return res.SetError(err)
+			return nil, nil, err
 		}
-		if err := pluginmanager.StartNewInstance(executable); err != nil {
+		if state, err = pluginmanager.StartNewInstance(executable); err != nil {
 			log.Printf("[WARN] StartServices plugin manager failed to start: %s", err)
-			return res.SetError(err)
+			return nil, nil, err
 		}
-		// set status to service started as started plugin manager
-		res.Status = ServiceStarted
 	}
-	return res
+	client, err := pluginmanager.NewPluginManagerClient(state)
+	if err != nil {
+		return nil, state, err
+	}
+	return client, state, nil
 }
 
 func postServiceStart(ctx context.Context, res *StartResult) error {
@@ -142,26 +169,30 @@ func postServiceStart(ctx context.Context, res *StartResult) error {
 	}
 	defer conn.Close(ctx)
 
-	statushooks.SetStatus(ctx, "Dropping legacy schema")
-	if err := dropLegacyInternalSchema(ctx, conn); err != nil {
-		// do not fail
-		// worst case scenario is that we have a couple of extra schema
-		// these won't be in the search path anyway
-		log.Println("[INFO] failed to drop legacy 'internal' schema", err)
-	}
-
 	// setup internal schema
-	// this includes setting the state of all connections in the connection_state table to pending
-	statushooks.SetStatus(ctx, "Setting up functions")
 	if err := setupInternal(ctx, conn); err != nil {
 		return err
 	}
-	// ensure connection stat etable contains entries for all connections in connection config
+
+	statushooks.SetStatus(ctx, "Initialize steampipe_connection table")
+
+	// ensure connection state table contains entries for all connections in connection config
 	// (this is to allow for the race condition between polling connection state and calling refresh connections,
 	// which does not update the connection_state with added connections until it has built the ConnectionUpdates
 	if err := initializeConnectionStateTable(ctx, conn); err != nil {
 		return err
 	}
+	if err := PopulatePluginTable(ctx, conn); err != nil {
+		return err
+	}
+
+	statushooks.SetStatus(ctx, "Create steampipe_server_settings table")
+	// create the server settings table
+	// this table contains configuration that this instance of the service
+	// is booting with
+	if err := setupServerSettingsTable(ctx, conn); err != nil {
+		return err
+	}
 
 	// create the clone_foreign_schema function
 	if _, err := executeSqlAsRoot(ctx, cloneForeignSchemaSQL); err != nil {
@@ -177,23 +208,13 @@ func postServiceStart(ctx context.Context, res *StartResult) error {
 		return sperr.WrapWithMessage(err, "failed to migrate db public schema")
 	}
 
-	// call initial refresh connections
-	// get plugin manager client
-	pluginManager, err := pluginmanager.GetPluginManager()
-	if err != nil {
-		return err
-	}
-	// ask the plugin manager to refresh connections
-	// this is executed asyncronously by the plugin manager
-	pluginManager.RefreshConnections(&pb.RefreshConnectionsRequest{})
-
-	statushooks.SetStatus(ctx, "Service startup complete")
+	statushooks.SetStatus(ctx, "Call initial refresh connections")
 	return nil
 }
 
 // StartDB starts the database if not already running
-func startDB(ctx context.Context, port int, listen StartListenType, invoker constants.Invoker) (res *StartResult) {
-	log.Printf("[TRACE] StartDB invoker %s", invoker)
+func startDB(ctx context.Context, listenAddresses []string, port int, invoker constants.Invoker) (res *StartResult) {
+	log.Printf("[TRACE] StartDB invoker %s (listenAddresses=%s, port=%d)", invoker, listenAddresses, port)
 	utils.LogTime("db.StartDB start")
 	defer utils.LogTime("db.StartDB end")
 	var postgresCmd *exec.Cmd
@@ -222,17 +243,23 @@ func startDB(ctx context.Context, port int, listen StartListenType, invoker cons
 	// remove the stale info file, ignoring errors - will overwrite anyway
 	_ = removeRunningInstanceInfo()
 
-	if err := utils.EnsureDirectoryPermission(getDataLocation()); err != nil {
-		return res.SetError(fmt.Errorf("%s does not have the necessary permissions to start the service", getDataLocation()))
+	if err := utils.EnsureDirectoryPermission(filepaths.GetDataLocation()); err != nil {
+		return res.SetError(fmt.Errorf("%s does not have the necessary permissions to start the service", filepaths.GetDataLocation()))
+	}
+
+	// Remove any old and expiring certificates
+	if err := removeExpiringSelfIssuedCertificates(); err != nil {
+		error_helpers.ShowWarning("failed to remove expired certificates")
+		log.Println("[TRACE] failed to remove expired certificates", err)
 	}
 
 	// Generate the certificate if it fails then set the ssl to off
-	if err := ensureSelfSignedCertificate(); err != nil {
+	if err := ensureCertificates(); err != nil {
 		error_helpers.ShowWarning("self signed certificate creation failed, connecting to the database without SSL")
 	}
 
-	if err := utils.IsPortBindable(port); err != nil {
-		return res.SetError(fmt.Errorf("cannot listen on port %d", constants.Bold(port)))
+	if err := utils.IsPortBindable(utils.GetFirstListenAddress(listenAddresses), port); err != nil {
+		return res.SetError(fmt.Errorf("cannot listen on port %d and %s %s. To check if there's any other steampipe services running, use %s", constants.Bold(port), utils.Pluralize("address", len(listenAddresses)), constants.Bold(strings.Join(listenAddresses, ",")), constants.Bold("steampipe service status --all")))
 	}
 
 	if err := migrateLegacyPasswordFile(); err != nil {
@@ -244,14 +271,14 @@ func startDB(ctx context.Context, port int, listen StartListenType, invoker cons
 		return res.SetError(err)
 	}
 
-	postgresCmd, err = startPostgresProcess(ctx, port, listen, invoker)
+	postgresCmd, err = startPostgresProcess(ctx, listenAddresses, port, invoker)
 	if err != nil {
 		return res.SetError(err)
 	}
 
 	// create a RunningInfo with empty database name
 	// we need this to connect to the service using 'root', required retrieve the name of the installed database
-	res.DbState = newRunningDBInstanceInfo(postgresCmd, port, "", password, listen, invoker)
+	res.DbState = newRunningDBInstanceInfo(postgresCmd, listenAddresses, port, "", password, invoker)
 	err = res.DbState.Save()
 	if err != nil {
 		return res.SetError(err)
@@ -345,22 +372,17 @@ func resolvePassword() (string, error) {
 	return password, nil
 }
 
-func startPostgresProcess(ctx context.Context, port int, listen StartListenType, invoker constants.Invoker) (*exec.Cmd, error) {
+func startPostgresProcess(ctx context.Context, listenAddresses []string, port int, invoker constants.Invoker) (*exec.Cmd, error) {
 	if error_helpers.IsContextCanceled(ctx) {
 		return nil, ctx.Err()
 	}
 
-	listenAddresses := "localhost"
-
-	if listen == ListenTypeNetwork {
-		listenAddresses = "*"
-	}
-
 	if err := writePGConf(ctx); err != nil {
 		return nil, err
 	}
 
 	postgresCmd := createCmd(ctx, port, listenAddresses)
+	log.Printf("[TRACE] startPostgresProcess - postgres command: %s", postgresCmd)
 
 	setupLogCollection(postgresCmd)
 	err := postgresCmd.Start()
@@ -391,17 +413,17 @@ func retrieveDatabaseNameFromService(ctx context.Context, port int) (string, err
 
 func writePGConf(ctx context.Context) error {
 	// Apply default settings in conf files
-	err := os.WriteFile(getPostgresqlConfLocation(), []byte(constants.PostgresqlConfContent), 0600)
+	err := os.WriteFile(filepaths.GetPostgresqlConfLocation(), []byte(constants.PostgresqlConfContent), 0600)
 	if err != nil {
 		return err
 	}
-	err = os.WriteFile(getSteampipeConfLocation(), []byte(constants.SteampipeConfContent), 0600)
+	err = os.WriteFile(filepaths.GetSteampipeConfLocation(), []byte(constants.SteampipeConfContent), 0600)
 	if err != nil {
 		return err
 	}
 
 	// create the postgresql.conf.d location, don't fail if it errors
-	err = os.MkdirAll(getPostgresqlConfDLocation(), 0700)
+	err = os.MkdirAll(filepaths.GetPostgresqlConfDLocation(), 0700)
 	if err != nil {
 		return err
 	}
@@ -417,15 +439,12 @@ func updateDatabaseNameInRunningInfo(ctx context.Context, databaseName string) (
 	return runningInfo, runningInfo.Save()
 }
 
-func createCmd(ctx context.Context, port int, listenAddresses string) *exec.Cmd {
+func createCmd(ctx context.Context, port int, listenAddresses []string) *exec.Cmd {
 	postgresCmd := exec.Command(
-		getPostgresBinaryExecutablePath(),
-		// by this time, we are sure that the port if free to listen to
+		filepaths.GetPostgresBinaryExecutablePath(),
+		// by this time, we are sure that the port is free to listen to
 		"-p", fmt.Sprint(port),
-		"-c", fmt.Sprintf("listen_addresses=\"%s\"", listenAddresses),
-		// NOTE: If quoted, the application name includes the quotes. Worried about
-		// having spaces in the APPNAME, but leaving it unquoted since currently
-		// the APPNAME is hardcoded to be steampipe.
+		"-c", fmt.Sprintf("listen_addresses=%s", strings.Join(listenAddresses, ",")),
 		"-c", fmt.Sprintf("application_name=%s", constants.AppName),
 		"-c", fmt.Sprintf("cluster_name=%s", constants.AppName),
 
@@ -435,11 +454,11 @@ func createCmd(ctx context.Context, port int, listenAddresses string) *exec.Cmd
 		// If ssl is off  it doesnot matter what we pass in the ssl_cert_file and ssl_key_file
 		// SSL will only get validated if ssl is on
 		"-c", fmt.Sprintf("ssl=%s", sslStatus()),
-		"-c", fmt.Sprintf("ssl_cert_file=%s", getServerCertLocation()),
-		"-c", fmt.Sprintf("ssl_key_file=%s", getServerCertKeyLocation()),
+		"-c", fmt.Sprintf("ssl_cert_file=%s", filepaths.GetServerCertLocation()),
+		"-c", fmt.Sprintf("ssl_key_file=%s", filepaths.GetServerCertKeyLocation()),
 
 		// Data Directory
-		"-D", getDataLocation())
+		"-D", filepaths.GetDataLocation())
 
 	postgresCmd.Env = append(os.Environ(), fmt.Sprintf("STEAMPIPE_INSTALL_DIR=%s", filepaths.SteampipeDir))
 
