@@ -7,7 +7,6 @@ import (
 
 	"github.com/Masterminds/semver/v3"
 	"github.com/hashicorp/hcl/v2"
-	"github.com/hashicorp/hcl/v2/hclsyntax"
 	"github.com/turbot/steampipe-plugin-sdk/v5/sperr"
 	"github.com/turbot/steampipe/pkg/ociinstaller"
 	"github.com/turbot/steampipe/pkg/version"
@@ -23,8 +22,8 @@ type Require struct {
 	modMap map[string]*ModVersionConstraint
 	// range of the definition of the require block
 	DeclRange hcl.Range
-	// range of the body of the require block
-	BodyRange hcl.Range
+	// range of the require block type
+	TypeRange hcl.Range
 }
 
 func NewRequire() *Require {
@@ -38,7 +37,7 @@ func (r *Require) Clone() *Require {
 	require.Plugins = r.Plugins
 	require.Mods = r.Mods
 	require.DeclRange = r.DeclRange
-	require.BodyRange = r.BodyRange
+	require.TypeRange = r.TypeRange
 
 	// we need to shallow copy the map
 	// if we don't, when the other one gets
@@ -75,7 +74,7 @@ func (r *Require) initialise(modBlock *hcl.Block) hcl.Diagnostics {
 
 	// set our Ranges
 	r.DeclRange = hcl_helpers.BlockRange(requireBlock)
-	r.BodyRange = requireBlock.Body.(*hclsyntax.Body).SrcRange
+	r.TypeRange = requireBlock.TypeRange
 
 	// build maps of plugin and mod blocks
 	pluginBlockMap := hcl_helpers.BlocksToMap(hcl_helpers.FindChildBlocks(requireBlock, BlockTypePlugin))
