@@ -3,7 +3,7 @@ package parse
 import (
 	"github.com/hashicorp/hcl/v2"
 	"github.com/hashicorp/hcl/v2/hclsyntax"
-	"github.com/turbot/steampipe/pkg/steampipeconfig/hclhelpers"
+	"github.com/turbot/go-kit/hcl_helpers"
 	"github.com/turbot/steampipe/pkg/steampipeconfig/modconfig"
 )
 
@@ -18,7 +18,7 @@ func AddReferences(resource modconfig.HclResource, block *hcl.Block, parseCtx *M
 	for _, attr := range block.Body.(*hclsyntax.Body).Attributes {
 		for _, v := range attr.Expr.Variables() {
 			for _, referenceBlockType := range modconfig.ReferenceBlocks {
-				if referenceString, ok := hclhelpers.ResourceNameFromTraversal(referenceBlockType, v); ok {
+				if referenceString, ok := hcl_helpers.ResourceNameFromTraversal(referenceBlockType, v); ok {
 					var blockName string
 					if len(block.Labels) > 0 {
 						blockName = block.Labels[0]
