@@ -4,21 +4,19 @@ import (
 	"fmt"
 	"strings"
 
-	"github.com/turbot/steampipe/pkg/steampipeconfig/modconfig"
-
+	"github.com/turbot/steampipe/pkg/error_helpers"
 	"github.com/turbot/steampipe/pkg/utils"
 )
 
 // RefreshConnectionResult is a structure used to contain the result of either a RefreshConnections or a NewLocalClient operation
 type RefreshConnectionResult struct {
-	modconfig.ErrorAndWarnings
+	error_helpers.ErrorAndWarnings
 	UpdatedConnections bool
-	Updates            *ConnectionUpdates
 	FailedConnections  map[string]string
 }
 
 func NewErrorRefreshConnectionResult(err error) *RefreshConnectionResult {
-	return &RefreshConnectionResult{ErrorAndWarnings: *modconfig.NewErrorsAndWarning(err)}
+	return &RefreshConnectionResult{ErrorAndWarnings: *error_helpers.NewErrorsAndWarning(err)}
 }
 
 func (r *RefreshConnectionResult) Merge(other *RefreshConnectionResult) {
@@ -42,7 +40,7 @@ func (r *RefreshConnectionResult) Merge(other *RefreshConnectionResult) {
 func (r *RefreshConnectionResult) String() string {
 	var op strings.Builder
 	if len(r.Warnings) > 0 {
-		op.WriteString(fmt.Sprintf("%s:\n\t%s", utils.Pluralize("Warning", len(r.Warnings)), strings.Join(r.Warnings, "\n\t")))
+		op.WriteString(fmt.Sprintf("%s:\n\t%s\n", utils.Pluralize("Warning", len(r.Warnings)), strings.Join(r.Warnings, "\n\t")))
 	}
 	if r.Error != nil {
 		op.WriteString(fmt.Sprintf("%s\n", r.Error.Error()))
