@@ -109,9 +109,6 @@ func (r *Runner) run(ctx context.Context) {
 	// remove log files older than 7 days
 	r.runJobAsync(ctx, func(_ context.Context) { db_local.TrimLogs() }, &waitGroup)
 
-	// validate and regenerate service SSL certificates
-	r.runJobAsync(ctx, func(_ context.Context) { validateServiceCertificates() }, &waitGroup)
-
 	// wait for all jobs to complete
 	waitGroup.Wait()
 
@@ -164,7 +161,7 @@ func showNotificationsForCommand(cmd *cobra.Command, cmdArgs []string) bool {
 	return !(isPluginUpdateCmd(cmd) ||
 		IsPluginManagerCmd(cmd) ||
 		isServiceStopCmd(cmd) ||
-		isBatchQueryCmd(cmd, cmdArgs) ||
+		IsBatchQueryCmd(cmd, cmdArgs) ||
 		isCompletionCmd(cmd))
 }
 
@@ -180,6 +177,6 @@ func IsPluginManagerCmd(cmd *cobra.Command) bool {
 func isPluginUpdateCmd(cmd *cobra.Command) bool {
 	return cmd.Name() == "update" && cmd.Parent() != nil && cmd.Parent().Name() == "plugin"
 }
-func isBatchQueryCmd(cmd *cobra.Command, cmdArgs []string) bool {
+func IsBatchQueryCmd(cmd *cobra.Command, cmdArgs []string) bool {
 	return cmd.Name() == "query" && len(cmdArgs) > 0
 }
