@@ -3,7 +3,7 @@ package main
 import (
 	"encoding/json"
 	"github.com/turbot/steampipe/pkg/version"
-	"io/ioutil"
+	"os"
 )
 
 type packageVersion struct {
@@ -14,7 +14,7 @@ func main() {
 	spVersionString := version.SteampipeVersion.String()
 	spVersion := packageVersion{Version: spVersionString}
 	versionsFile, _ := json.MarshalIndent(spVersion, "", " ")
-	err := ioutil.WriteFile("build/versions.json", versionsFile, 0644)
+	err := os.WriteFile("build/versions.json", versionsFile, 0644)
 	if err != nil {
 		panic(err)
 	}
