@@ -67,7 +67,7 @@ const useDashboardWebSocket = (
       return;
     }
     const typedEvent = lastJsonMessage as ReceivedSocketMessagePayload;
-    if (!typedEvent.action) {
+    if (!typedEvent || !typedEvent.action) {
       return;
     }
     eventHandler(typedEvent);
